@@ -62,7 +62,8 @@ extern PrintOptions printops;
 extern bool ignore_locale;
 extern bool title_modified;
 extern bool minimal_mode;
-extern gint hidden_x, hidden_y;
+extern gint hidden_x, hidden_y, hidden_monitor;
+extern bool hidden_monitor_primary;
 bool check_version = false;
 string custom_title;
 
@@ -84,7 +85,7 @@ bool do_imaginary_j = false;
 QalculateDateTime last_version_check_date;
 
 static GOptionEntry options[] = {
-	{"file", 'f', 0, G_OPTION_ARG_STRING, NULL, N_("Execute expressions and commands from a file"), NULL},
+	{"file", 'f', 0, G_OPTION_ARG_STRING, NULL, N_("Execute expressions and commands from a file"), N_("FILE")},
 	{"new-instance", 'n', 0, G_OPTION_ARG_NONE, NULL, N_("Start a new instance of the application"), NULL},
 	{"version", 'v', 0, G_OPTION_ARG_NONE, NULL, N_("Display the application version"), NULL},
 	{"title", 0, 0, G_OPTION_ARG_STRING, NULL, N_("Specify the window title"), N_("TITLE")},
@@ -354,7 +355,31 @@ static void qalculate_activate(GtkApplication *app) {
 	if(list) {
 		if(hidden_x >= 0) {
 			gtk_widget_show(GTK_WIDGET(list->data));
-			gtk_window_move(GTK_WINDOW(list->data), hidden_x, hidden_y);
+			GdkDisplay *display = gtk_widget_get_display(GTK_WIDGET(list->data));
+#if GTK_MAJOR_VERSION > 3 || GTK_MINOR_VERSION >= 22
+			GdkMonitor *monitor = NULL;
+			if(hidden_monitor_primary) monitor = gdk_display_get_primary_monitor(display);
+			if(!monitor && hidden_monitor > 0) gdk_display_get_monitor(display, hidden_monitor - 1);
+			if(monitor) {
+				GdkRectangle area;
+				gdk_monitor_get_workarea(monitor, &area);
+#else
+			GdkScreen *screen = gdk_display_get_default_screen(display);
+			int i = -1;
+			if(hidden_monitor_primary) i = gdk_screen_get_primary_monitor(screen);
+			if(i < 0 && hidden_monitor > 0 && hidden_monitor < gdk_screen_get_n_monitors(screen)) i = hidden_monitor;
+			if(i >= 0) {
+				GdkRectangle area;
+				gdk_screen_get_monitor_workarea(screen, i, &area);
+#endif
+				gint w = 0, h = 0;
+				gtk_window_get_size(GTK_WINDOW(list->data), &w, &h);
+				if(hidden_x + w > area.width) hidden_x = area.width - w;
+				if(hidden_y + h > area.height) hidden_y = area.height - h;
+				gtk_window_move(GTK_WINDOW(list->data), hidden_x + area.x, hidden_y + area.y);
+			} else {
+				gtk_window_move(GTK_WINDOW(list->data), hidden_x, hidden_y);
+			}
 			hidden_x = -1;
 		}
 #ifdef _WIN32
@@ -469,7 +494,31 @@ static gint qalculate_command_line(GtkApplication *app, GApplicationCommandLine
 		}
 		if(hidden_x >= 0) {
 			gtk_widget_show(GTK_WIDGET(gtk_builder_get_object(main_builder, "main_window")));
-			gtk_window_move(GTK_WINDOW(gtk_builder_get_object(main_builder, "main_window")), hidden_x, hidden_y);
+			GdkDisplay *display = gtk_widget_get_display(GTK_WIDGET(gtk_builder_get_object(main_builder, "main_window")));
+#if GTK_MAJOR_VERSION > 3 || GTK_MINOR_VERSION >= 22
+			GdkMonitor *monitor = NULL;
+			if(hidden_monitor_primary) monitor = gdk_display_get_primary_monitor(display);
+			if(!monitor && hidden_monitor > 0) gdk_display_get_monitor(display, hidden_monitor - 1);
+			if(monitor) {
+				GdkRectangle area;
+				gdk_monitor_get_workarea(monitor, &area);
+#else
+			GdkScreen *screen = gdk_display_get_default_screen(display);
+			int i = -1;
+			if(hidden_monitor_primary) i = gdk_screen_get_primary_monitor(screen);
+			if(i < 0 && hidden_monitor > 0 && hidden_monitor < gdk_screen_get_n_monitors(screen)) i = hidden_monitor;
+			if(i >= 0) {
+				GdkRectangle area;
+				gdk_screen_get_monitor_workarea(screen, i, &area);
+#endif
+				gint w = 0, h = 0;
+				gtk_window_get_size(GTK_WINDOW(gtk_builder_get_object(main_builder, "main_window")), &w, &h);
+				if(hidden_x + w > area.width) hidden_x = area.width - w;
+				if(hidden_y + h > area.height) hidden_y = area.height - h;
+				gtk_window_move(GTK_WINDOW(gtk_builder_get_object(main_builder, "main_window")), hidden_x + area.x, hidden_y + area.y);
+			} else {
+				gtk_window_move(GTK_WINDOW(gtk_builder_get_object(main_builder, "main_window")), hidden_x, hidden_y);
+			}
 			hidden_x = -1;
 		}
 #ifdef _WIN32
@@ -482,7 +531,7 @@ static gint qalculate_command_line(GtkApplication *app, GApplicationCommandLine
 			gtk_text_buffer_set_text(GTK_TEXT_BUFFER(gtk_builder_get_object(main_builder, "expressionbuffer")), calc_arg.c_str(), -1);
 			execute_expression();
 		} else if(allow_multiple_instances < 0 && file_arg.empty()) {
-			GtkWidget *edialog = gtk_message_dialog_new(GTK_WINDOW(gtk_builder_get_object(main_builder, "main_window")), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, _("By default, only one instance (one main window) of %s is allowed.\n\nIf multiple instances are opened simultaneously, only the definitions (variables, functions, etc.), mode, preferences, and history of the last closed window will be saved.\n\nDo you, despite this, want to change the default bahvior and allow multiple simultaneous instances?"), "Qalculate!");
+			GtkWidget *edialog = gtk_message_dialog_new(GTK_WINDOW(gtk_builder_get_object(main_builder, "main_window")), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, _("By default, only one instance (one main window) of %s is allowed.\n\nIf multiple instances are opened simultaneously, only the definitions (variables, functions, etc.), mode, preferences, and history of the last closed window will be saved.\n\nDo you, despite this, want to change the default behavior and allow multiple simultaneous instances?"), "Qalculate!");
 			allow_multiple_instances = gtk_dialog_run(GTK_DIALOG(edialog)) == GTK_RESPONSE_YES;
 			save_preferences(false);
 			gtk_widget_destroy(edialog);
@@ -517,7 +566,7 @@ int main (int argc, char *argv[]) {
 	gchar *gstr_file = g_build_filename(getLocalDir().c_str(), "qalculate-gtk.cfg", NULL);
 	FILE *file = fopen(gstr_file, "r");
 	char line[10000];
-	string stmp;
+	string stmp, lang;
 	if(file) {
 		while(true) {
 			if(fgets(line, 10000, file) == NULL) break;
@@ -526,6 +575,17 @@ int main (int argc, char *argv[]) {
 				break;
 			} else if(strcmp(line, "ignore_locale=0\n") == 0) {
 				break;
+			} else if(strncmp(line, "language=", 9) == 0) {
+				lang = line + sizeof(char) * 9;
+				remove_blank_ends(lang);
+				if(!lang.empty()) {
+#	ifdef _WIN32
+					_putenv_s("LANG", lang.c_str());
+#	else
+					setenv("LANG", lang.c_str(), 1);
+#	endif
+				}
+				break;
 			}
 		}
 		fclose(file);
